# predictablity&preview
#2019
# 64 young participants

library(lmerTest)
library(lattice)
library(MASS)
library(plyr) 
library(ggplot2)
library(emmeans)
library(BayesFactor)
library(lsmeans)

rm(list=ls())
datafile = read.csv(file.choose(), sep = ",", dec = ".")
colnames(datafile)

#####################################################################################################
#####################################################################################################
# choose dependent variable
measure = "IA_SKIP"
datafile$depvar = datafile[,measure]

# Work out which colums the fixed and random factors are in
datafile$pp = datafile[,1]
datafile$Item = datafile[,2]
datafile$Preview = datafile[,3]
datafile$Predictability = datafile[,4]
datafile$Condition = datafile[,5]
datafile$Launch_site_NF = datafile[,6]
datafile$SacIn_NF = datafile[,7]
# Let's make sure all the variables are from the correct class
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$Item = as.factor(datafile$Item)
datafile$Preview = factor(datafile$Preview, order=TRUE, levels = c("V","I"))
datafile$Predictability = factor(datafile$Predictability, order=TRUE, levels = c("H","L"))
datafile$Condition = factor(datafile$Condition, order=TRUE, levels = c("VH","VL","IH","IL"))
datafile$Launch_site_NF = factor(datafile$Launch_site_NF, order=TRUE, levels = c("N","F"))
datafile$SacIn_NF = factor(datafile$SacIn_NF, order=TRUE, levels = c("N","F"))

#SLIDING CONTRASTS
contrasts(datafile$Predictability) <- contr.sdif(2)  
contrasts(datafile$Predictability)
contrasts(datafile$Preview) <- contr.sdif(2)
contrasts(datafile$Preview) 
contrasts(datafile$Launch_site_NF) <- contr.sdif(2)
contrasts(datafile$SacIn_NF) <- contr.sdif(2)
#####################################################################################################
#####################################################################################################
crit = 3
nrcolumns = ncol(datafile)   # We'll be using this for cleanup later
#let's first have a look
head(datafile)

# make a new datafile with fixation durations > 0 ms
between1 = datafile[datafile$depvar > 0, ]
head(between1)
#make a matrix with the means per subject and per condition for the dependent variable
mean.matrix = tapply(between1$depvar, list(between1$pp), mean, na.rm = T)

#make a matrix with the standard deviations per subject and per condition for the dependent variable

sd.matrix = tapply(between1$depvar, list(between1$pp), sd, na.rm = T)

#add this data to the actual dataframe
for(i in 1:nrow(between1)){between1$mean.sc[i] = mean.matrix[between1$pp[i]]}
for(i in 1:nrow(between1)){between1$sd.sc[i] = sd.matrix[between1$pp[i]]}


#calculate z-scores
for(i in 1:nrow(between1)) {between1$zscore[i] = (between1$depvar[i] - between1$mean.sc[i])/between1$sd.sc[i]}

# assign a zero value to cells with only 1 observation
between1$zscore[is.na(between1$zscore)] = 0

#make new matrix with only standard deviations below a certain criterium of z-score (in absolute value)

result = between1[abs(between1$zscore) < 3,]

#you might want to clean up this data file by removing the added columns
result =  result[,1:nrcolumns]
datafile <-result
nrow(datafile)
#####################################################################################################
#####################################################################################################

# Do we need to log transform?
qqnorm(datafile$depvar)

# If yes
datafile$depvar = log(datafile$depvar)
qqnorm(datafile$depvar)
#####################################################################################################
#####################################################################################################
(table1 <- ddply(datafile, .(Predictability), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N)))
(table2 <- ddply(datafile, .(Preview), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N)))
(table3 <- ddply(datafile, .(Preview, Predictability), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N) ))
(table4 <- ddply(datafile, .(Launch_site_NF), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N)))
(table5 <- ddply(datafile, .(SacIn_NF), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N)))
(table6 <- ddply(datafile, .(Launch_site_NF, Predictability, Preview), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N)))
(table7 <- ddply(datafile, .(SacIn_NF, Predictability, Preview), summarise, M=mean(depvar, na.rm = TRUE), SD=sd(depvar, na.rm = TRUE), N=length(depvar[!is.na(depvar)]), SE=SD/sqrt(N)))

#########################################################################################################
#########################################################################################################

############################################
# predictability, preview, preview:predictability(1,0)

glmer1 = glmer(depvar ~ Predictability * Preview  + (1+Predictability * Preview |pp) + (1|Item), datafile, family = binomial)
summary(glmer1)
confint(glmer1, method="Wald")

glmer2 = glmer(depvar ~ Predictability * Preview + (1+Predictability|pp) + (1|Item), datafile, family = binomial)
summary(glmer2)
confint(glmer2, method="Wald")

glmer3 = glmer(depvar ~ Predictability * Preview + (1+Preview|pp) + (1|Item), datafile, family = binomial)
summary(glmer3)
confint(glmer3, method="Wald")

glmer4 = glmer(depvar ~ Predictability * Preview + (1|pp)  + (1|Item), datafile, family = binomial)
summary(glmer4)
confint(glmer4, method="Wald")
############################################

lmerFull = lmer(depvar ~  Predictability * Preview + (1+Predictability*Preview|Participant) + (1+Predictability*Preview|Item), datafile, control = lmerControl(optCtrl = list(maxfun = 20000)))
summary(lmerFull, corr = FALSE)
confint(lmerFull)

lmer1 = lmer(depvar ~Predictability * Preview  + (1+Predictability*Preview|Participant) + (1|Item), datafile, control = lmerControl(optCtrl = list(maxfun = 20000)))
summary(lmer1, corr = FALSE)
confint(lmer1)

lmer2 = lmer(depvar ~ Predictability * Preview  + (1+Preview*Predictability|Participant) + (1|Item), datafile)
summary(lmer2, corr = FALSE)
confint(lmer2, method="Wald")

lmer2 = lmer(depvar ~ Predictability * Preview  + (1+Predictability+Preview|pp) + (1|Item), datafile)
summary(lmer2, corr = FALSE)
confint(lmer2, method="Wald")

lmer3 = lmer(depvar ~ Predictability * Preview  + (1+Predictability|Participant) + (1|Item), datafile)
summary(lmer3, corr = FALSE)
confint(lmer3, method="Wald")

lmer4 = lmer(depvar ~ Predictability * Preview  + (1+Preview|Participant) + (1|Item), datafile)
summary(lmer4, corr = FALSE)
confint(lmer4, method="Wald")

lmer5 = lmer(depvar ~Predictability * Preview*Launch_site_NF + (1+Predictability * Preview|pp) + (1|Item), datafile)
summary(lmer5, corr = FALSE)

anova(lmerFull, lmer1)
#########################################################################################################
#########################################################################################################
##simple effect analysis
contrast.matrix <- matrix(c(   
  -1, 1, 0, 0,        #Valid: high pred vs low pred
  0, 0, -1, +1), 4, 2,  #Invalid: high pred vs low pred
  dimnames=list(c("VH","VL","IH","IL"), 
                c("V_LvsH", "I_LvsH")))

# Perform some magic (needs to inverse it before assigning to the contrasts)
inv.contrast.matrix <- matrix(t(ginv(contrast.matrix)), 4, 2,
                              dimnames=list(c("VH","VL","IH","IL"), 
                                            c("V_LvsH", "I_LvsH")))
(contrasts(datafile$Condition) <- fractions(inv.contrast.matrix))

depvar.lmerCondition = lmer(depvar ~ Condition + (1|pp) + (1|Item),  datafile)
summary(depvar.lmerCondition, corr = FALSE)

depvar.glmerCondition = glmer(depvar ~ Condition + (1|pp) + (1|Item), family=binomial, datafile)
summary(depvar.glmerCondition, corr = FALSE)
#########################################################################################################
#########################################################################################################
#Interaction between the three factors,
Near = lmer(depvar ~ Predictability*Preview*Launch_site_NF + (1+Predictability*Preview |pp)+ (1 |Item), datafile)
summary(Near, corr = FALSE)
Far = lmer(depvar ~ Predictability*Preview*Launch_site_NF + (1+Predictability*Preview |pp)+ (1 |Item) , datafile)
summary(Far, corr = FALSE)

Near = lmer(depvar ~ Predictability*Preview*SacIn_NF + (1+Predictability*Preview |pp)+ (1 |Item), datafile)
summary(Near, corr = FALSE)
Far = lmer(depvar ~ Predictability*Preview*SacIn_NF + (1+Predictability*Preview |pp)+ (1 |Item) , datafile)
summary(Far, corr = FALSE)
#########################################################################################################
#########################################################################################################
##Bayes Analyses

iterations <- 100000  
rscaleFixed <- 0.5    # scaling factor for g-priors for fixed effects - this is the same as the default (cauchy)
whichRandom <- c("Participant,Item")  # specify random effects

colnames(datafile)
datafile$depvar = datafile[,8]
datafile <- datafile[,c(1,2,3,4,5,8)]

datafile$pp = datafile[,1]
datafile$Item = datafile[,2]
datafile$Predictability = datafile[,4]
datafile$Preview = datafile[,3]
datafile$Condition = datafile[,5]
datafile$depvar = datafile[,6]
datafile$depvar = as.numeric(datafile$depvar)
datafile$pp = as.factor(datafile$pp)
datafile$Item = as.factor(datafile$Item)
datafile$Predictability = factor(datafile$Predictability, order=TRUE, levels = c("H","L"))
datafile$Preview = factor(datafile$Preview, order=TRUE, levels = c("V","I"))
datafile$Condition = factor(datafile$Condition, order=TRUE, levels = c("VH","VL","IH","IL"))

sum(is.na(datafile$depvar))
datafile <- na.omit(datafile)

bfFull <- lmBF (depvar ~ Predictability*Preview , whichRandom = whichRandom, rscaleFixed = rscaleFixed, iterations = iterations, datafile)
bfFull
bfMain <- lmBF (depvar ~Predictability+Preview, whichRandom = whichRandom, rscaleFixed = rscaleFixed, iterations = iterations, datafile)
bfMain 

bfMain/bfFull

#########################################################################################################
#########################################################################################################
##Power analysis
library(simr)
simdata <- read.csv(file.choose(), sep = ",", dec = ".")
colnames(simdata)

##
b = c(215.4, 33.11, 8.48, 16.6)    
V1 <- 834.8
s <- 67.6

model1 <- makeLmer(y ~ Preview * Predictability + (1|Participant), fixef=b, VarCorr=V1, sigma=s, data=simdata)
summary(model1)

powercalculation  <- powerSim(model1, nsim=10000, fixed("Preview:Predictability"))
powercalculation   


